==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/DescriptionTreeAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { TypeDescriptionMetadata } from "./TypeDescriptionMetadata";
import { stringEndsWith } from "./string";
/**
 * @hidden
 */
var DescriptionTreeAction = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DescriptionTreeAction, _super);
    function DescriptionTreeAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = 0;
        _this.c = null;
        _this.b = null;
        _this.d = null;
        _this.j = null;
        _this.h = null;
        _this.g = null;
        _this.f = 0;
        _this.e = 0;
        return _this;
    }
    DescriptionTreeAction.prototype.i = function (a) {
        var b = this.j;
        if (this.d != null) {
            b = this.d.j(a);
        }
        else {
            if (TypeDescriptionMetadata.shouldCamelize(a)) {
                b = TypeDescriptionMetadata.camelize(this.j);
            }
        }
        if (stringEndsWith(b, "Ref")) {
            b = b.substr(0, b.length - ("Ref").length);
        }
        return b;
    };
    DescriptionTreeAction.$t = markType(DescriptionTreeAction, 'DescriptionTreeAction');
    return DescriptionTreeAction;
}(Base));
export { DescriptionTreeAction };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/DescriptionTreeAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { TypeDescriptionMetadata } from "./TypeDescriptionMetadata";
import { stringEndsWith } from "./string";
/**
 * @hidden
 */
var DescriptionTreeAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DescriptionTreeAction, _super);
    function DescriptionTreeAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = 0;
        _this.c = null;
        _this.b = null;
        _this.d = null;
        _this.j = null;
        _this.h = null;
        _this.g = null;
        _this.f = 0;
        _this.e = 0;
        return _this;
    }
    DescriptionTreeAction.prototype.i = function (a) {
        var b = this.j;
        if (this.d != null) {
            b = this.d.k(a);
        }
        else {
            if (TypeDescriptionMetadata.shouldCamelize(a)) {
                b = TypeDescriptionMetadata.camelize(this.j);
            }
        }
        if (stringEndsWith(b, "Ref")) {
            b = b.substr(0, b.length - ("Ref").length);
        }
        return b;
    };
    DescriptionTreeAction.$t = markType(DescriptionTreeAction, 'DescriptionTreeAction');
    return DescriptionTreeAction;
}(Base));
export { DescriptionTreeAction };
